==> ad_blueprint-6.x-2.4.tar.gz: ad_blueprint/theme-settings.php <==
<?php
// $Id$

function ad_blueprint_settings($saved_settings) {
  // Set the default values for the theme variables
  $defaults = array(
    'ad_blueprint_layout' => 'fluid',
  );
  
  // Merge the variables and their default values
  $settings = array_merge($defaults, $saved_settings);
  
  // Layout Type
  $form['ad_blueprint_layout'] = array(
    '#type' => 'select',
    '#title' => t('Layout Type'),
    '#default_value' => $settings['ad_blueprint_layout'],
    '#options' => array(
      'fixed_800' => t('Fixed - 800px'),
      'fixed_960' => t('Fixed - 960px'),
      'fixed_1000' => t('Fixed - 1000px'),
      'fixed_1024' => t('Fixed - 1024px'),
      'fluid_90' => t('Fluid - 90%'),
      'fluid_95' => t('Fluid - 95%'),
      'fluid_98' => t('Fluid - 98%'),
      'fluid' => t('Fluid - 100%'),
    ),
    '#description' => t('This will determine the width of your site layout. All layouts are center aligned.
      <ul class="tips">
        <li><strong>Fixed</strong> Sets the same width with all screens, in px.</li>
        <li><strong>Fluid</strong> Will automatically size to fit the the screen width, or a proportion of the screen width.</li>
    </ul>'),
  );

  $form['ad_blueprint_css'] = array(
    '#type' => 'fieldset',
    '#title' => 'Custom CSS Generation',
    '#description' =>  _ad_blueprint_write_css(),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  return $form;
}

function _ad_blueprint_build_css() {
  
  // grab the current theme settings
  $theme_settings = variable_get('theme_ad_blueprint_settings', '');
  
  // build an array of only the theme related settings
  $setting = array();
  foreach ($theme_settings as $key => $value) {
    if (strpos($key, 'ad_blueprint_') !== FALSE) {
      $setting[$key] = $value;
    }
  }
  
  // handle custom settings for each case
  $custom_css = array();
  
  foreach ($setting as $key => $value) {
    switch ($key) {
      
      case 'ad_blueprint_layout':
        switch ($value) {
          case 'fluid':
            $width = '100%';
          break;
          case 'fluid_98':
            $width = '98%';
          break;
          case 'fluid_95':
            $width = '95%';
          break;
          case 'fluid_90':
            $width = '90%';
          break;
          case 'fixed_800':
            $width = '800px';
          break;
          case 'fixed_960':
            $width = '960px';
          break;
          case 'fixed_1000':
            $width = '1000px';
          break;
          case 'fixed_1024': default:
            $width = '1024px';
          break;
        }
        $custom_css[] = 'body #wrapper4 { width: '. $width .'; }';
      break;
     
    }
  }
  return implode("\r\n", $custom_css);
}

function _ad_blueprint_write_css() {
  // Set the location of the custom.css file
  $file_path = file_directory_path() .'/ad_blueprint/custom.css';
  
  // If the directory doesn't exist, create it
  file_check_directory(dirname($file_path), FILE_CREATE_DIRECTORY);
  
  // Generate the CSS
  $file_contents = _ad_blueprint_build_css();
  $output = '<div class="description">'. t('This CSS is generated by the settings chosen above and placed in the files directory: '. l($file_path, $file_path) .'. The file is generated each time this page (and only this page) is loaded. <strong class="marker">Make sure to refresh your page to see the changes</strong>') .'</div>';
  
  file_save_data($file_contents, $file_path, FILE_EXISTS_REPLACE);
  
  return $output;
  
}

// Theme Settings Generated CSS
$custom_css = file_directory_path() .'/ad_blueprint/custom.css';
if (file_exists($custom_css)) {
  drupal_add_css($custom_css, 'theme', 'all', TRUE);
}

==> ad_blueprint-6.x-2.5.tar.gz: ad_blueprint/theme-settings.php <==
<?php
// $Id$

function ad_blueprint_settings($saved_settings) {
  // Set the default values for the theme variables
  $defaults = array(
    'ad_blueprint_layout' => 'fluid',
  );
  
  // Merge the variables and their default values
  $settings = array_merge($defaults, $saved_settings);
  
  // Layout Type
  $form['ad_blueprint_layout'] = array(
    '#type' => 'select',
    '#title' => t('Layout Type'),
    '#default_value' => $settings['ad_blueprint_layout'],
    '#options' => array(
      'fixed_800' => t('Fixed - 800px'),
      'fixed_960' => t('Fixed - 960px'),
      'fixed_1000' => t('Fixed - 1000px'),
      'fixed_1024' => t('Fixed - 1024px'),
      'fluid_90' => t('Fluid - 90%'),
      'fluid_95' => t('Fluid - 95%'),
      'fluid_98' => t('Fluid - 98%'),
      'fluid' => t('Fluid - 100%'),
    ),
    '#description' => t('This will determine the width of your site layout. All layouts are center aligned.
      <ul class="tips">
        <li><strong>Fixed</strong> Sets the same width with all screens, in px.</li>
        <li><strong>Fluid</strong> Will automatically size to fit the the screen width, or a proportion of the screen width.</li>
    </ul>'),
  );

  $form['ad_blueprint_css'] = array(
    '#type' => 'fieldset',
    '#title' => 'Custom CSS Generation',
    '#description' =>  _ad_blueprint_write_css(),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  return $form;
}

function _ad_blueprint_build_css() {
  
  // grab the current theme settings
  $theme_settings = variable_get('theme_ad_blueprint_settings', array());

  // build an array of only the theme related settings
  $setting = array();
  foreach ($theme_settings as $key => $value) {
    if (strpos($key, 'ad_blueprint_') !== FALSE) {
      $setting[$key] = $value;
    }
  }
  
  // handle custom settings for each case
  $custom_css = array();
  
  foreach ($setting as $key => $value) {
    switch ($key) {
      
      case 'ad_blueprint_layout':
        switch ($value) {
          case 'fluid':
            $width = '100%';
          break;
          case 'fluid_98':
            $width = '98%';
          break;
          case 'fluid_95':
            $width = '95%';
          break;
          case 'fluid_90':
            $width = '90%';
          break;
          case 'fixed_800':
            $width = '800px';
          break;
          case 'fixed_960':
            $width = '960px';
          break;
          case 'fixed_1000':
            $width = '1000px';
          break;
          case 'fixed_1024': default:
            $width = '1024px';
          break;
        }
        $custom_css[] = 'body #wrapper4 { width: '. $width .'; }';
      break;
     
    }
  }
  return implode("\r\n", $custom_css);
}

function _ad_blueprint_write_css() {
  // Set the location of the custom.css file
  $file_path = file_directory_path() .'/ad_blueprint/custom.css';
  
  // If the directory doesn't exist, create it
  file_check_directory(dirname($file_path), FILE_CREATE_DIRECTORY);
  
  // Generate the CSS
  $file_contents = _ad_blueprint_build_css();
  $output = '<div class="description">'. t('This CSS is generated by the settings chosen above and placed in the files directory: '. l($file_path, $file_path) .'. The file is generated each time this page (and only this page) is loaded. <strong class="marker">Make sure to refresh your page to see the changes</strong>') .'</div>';
  
  file_save_data($file_contents, $file_path, FILE_EXISTS_REPLACE);
  
  return $output;
  
}

// Theme Settings Generated CSS
$custom_css = file_directory_path() .'/ad_blueprint/custom.css';
if (file_exists($custom_css)) {
  drupal_add_css($custom_css, 'theme', 'all', TRUE);
}
